@@ -9,10 +9,13 @@ class Metadata:
     certificate_intermediate_ca :bool = field(default_factory=bool)
     certificate_private_key_pem :bytes = field(default_factory=bytes)
     certificate_public_key_type :str = field(default_factory=str)
-    certificate_key_size :int = field(default_factory=int)
+    certificate_public_key_curve :str = field(default_factory=str)
+    certificate_public_key_exponent :int = field(default_factory=int)
+    certificate_public_key_size :int = field(default_factory=int)
     certificate_serial_number :str = field(default_factory=str)
     certificate_serial_number_decimal :int = field(default_factory=int)
     certificate_serial_number_hex :str = field(default_factory=str)
+    certificate_version :int = field(default_factory=int)
     certificate_subject :str = field(default_factory=str)
     certificate_issuer :str = field(default_factory=str)
     certificate_issuer_country :str = field(default_factory=str)
@@ -23,6 +26,7 @@ class Metadata:
     certificate_md5_fingerprint :str = field(default_factory=str)
     certificate_not_before :str = field(default_factory=str)
     certificate_not_after :str = field(default_factory=str)
+    certificate_expired :bool = field(default_factory=bool)
     certificate_common_name :str = field(default_factory=str)
     certificate_san :list = field(default_factory=list)
     certificate_subject_key_identifier :str = field(default_factory=str)
@@ -30,7 +34,7 @@ class Metadata:
     certificate_extensions :list = field(default_factory=list)
     certificate_is_self_signed :bool = field(default_factory=bool)
     client_certificate_expected :bool = field(default_factory=bool)
-    certificate_validation_type :str = field(default_factory=str) # None, DNS, Extended, Organisation
+    certificate_validation_type :str = field(default_factory=str)
     certification_authority_authorization :bool = field(default_factory=bool)
     revocation_ocsp_stapling :bool = field(default_factory=bool)
     revocation_ocsp_must_staple :bool = field(default_factory=bool)
@@ -38,8 +42,10 @@ class Metadata:
     revocation_ocsp_response :str = field(default_factory=str)
     revocation_ocsp_reason :str = field(default_factory=str)
     revocation_ocsp_time :str = field(default_factory=str)
+    revocation_crlite :bool = field(default_factory=bool)
     sni_support :bool = field(default_factory=bool)
     negotiated_protocol :str = field(default_factory=str)
+    offered_tls_versions :list = field(default_factory=list)
     negotiated_cipher :str = field(default_factory=str)
     weak_cipher :bool = field(default_factory=bool)
     strong_cipher :bool = field(default_factory=bool)
@@ -50,8 +56,14 @@ class Metadata:
     session_resumption_ticket_hint :bool = field(default_factory=bool)
     client_renegotiation :bool = field(default_factory=bool)
     dnssec :bool = field(default_factory=bool)
-    scsv_support :bool = field(default_factory=bool)
+    dnssec_algorithm :str = field(default_factory=str)
+    scsv :bool = field(default_factory=bool)
+    preferred_protocol :str = field(default_factory=str)
     compression_support :bool = field(default_factory=bool)
+    tls_version_intolerance :bool = field(default_factory=bool)
+    tls_version_intolerance_versions :list = field(default_factory=list)
+    tls_version_interference :bool = field(default_factory=bool)
+    tls_version_interference_versions :list = field(default_factory=list)
     peer_address :str = field(default_factory=str)
     http_expect_ct_report_uri :bool = field(default_factory=bool)
     http_hsts :bool = field(default_factory=bool)
@@ -70,3 +82,15 @@ class Metadata:
     http2_cleartext_support :bool = field(default_factory=bool)
     port :int = 443
     possible_phish_or_malicious :bool = field(default_factory=bool)
+    trust_apple_legacy :bool = field(default_factory=bool)
+    trust_apple_legacy_status :str = field(default_factory=str)
+    trust_ccadb :bool = field(default_factory=bool)
+    trust_ccadb_status :str = field(default_factory=str)
+    trust_java :bool = field(default_factory=bool)
+    trust_java_status :str = field(default_factory=str)
+    trust_android :bool = field(default_factory=bool)
+    trust_android_status :str = field(default_factory=str)
+    trust_linux :bool = field(default_factory=bool)
+    trust_linux_status :str = field(default_factory=str)
+    trust_certifi :bool = field(default_factory=bool)
+    trust_certifi_status :str = field(default_factory=str)
